#
# spec file for package python-google-api-core
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-google-api-core
Version:        2.19.2
Release:        1.1
Summary:        Google API client core library
License:        Apache-2.0
URL:            https://github.com/googleapis/python-api-core
Source:         https://files.pythonhosted.org/packages/source/g/google_api_core/google_api_core-%{version}.tar.gz
# https://github.com/googleapis/python-api-core/issues/377
Patch0:         python-google-api-core-no-mock.patch
BuildRequires:  %{python_module google-auth >= 2.14.1}
BuildRequires:  %{python_module googleapis-common-protos >= 1.53.0}
BuildRequires:  %{python_module grpcio >= 1.33.2}
BuildRequires:  %{python_module grpcio-status >= 1.33.2}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module proto-plus >= 1.22.3 with %python-proto-plus < 2.0.0dev0}
BuildRequires:  %{python_module protobuf >= 3.19.5 with %python-protobuf < 5.0.0.dev0}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module requests >= 2.18.0}
BuildRequires:  %{python_module setuptools >= 40.3.0}
BuildRequires:  %{python_module wheel}
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-google-api-core < %{version}
%endif
# START TESTING SECTION
%if %{with test}
BuildRequires:  %{python_module google-api-core >= %{version}}
BuildRequires:  %{python_module proto-plus}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
%endif
# END TESTING SECTION
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-google-auth >= 2.14.1
Requires:       python-googleapis-common-protos >= 1.53.0
Requires:       python-grpcio >= 1.33.2
Requires:       python-grpcio-status >= 1.33.2
Requires:       python-pytz
Requires:       python-requests >= 2.18.0
Requires:       python-setuptools >= 40.3.0
Requires:       (python-proto-plus >= 1.22.3 with python-proto-plus < 2.0.0dev0)
Requires:       (python-protobuf >= 3.19.5 with python-protobuf < 5.0.0.dev0)
BuildArch:      noarch
%python_subpackages

%description
Core Library for Google Client Libraries.

%prep
%autosetup -p1 -n google_api_core-%{version}

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%pytest
%endif

%clean

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/google/api_core
%{python_sitelib}/google_api_core-%{version}*-info
%endif

%changelog
* Tue Sep  3 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.19.2
  * Fail gracefully if could not import `rpc_status` module (#680)
- Adjust upstream source name in spec file
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 2.19.1:
  * Add support for protobuf 5.x
  * Ignore unknown fields in rest streaming.
* Thu May 16 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.19.0
  * Add google.api_core.version_header (#638)
- from version 2.18.0
  * Add common logic for supporting universe domain (#621)
  * Add _registered_method to grpc ChannelStub (#614)
  * **deps:** Require proto-plus >= 1.22.3 (#626)
- from version 2.17.1
  * Resolve issue handling protobuf responses in rest streaming (#604)
- from version 2.17.0
  * Add attempt_direct_path argument to create_channel (#583)
  * Retry constructors methods support None (#592)
- from version 2.16.2
  * Spelling error `a,out` -> `amount` (#596)
- from version 2.16.1
  * Fix broken import for google.api_core.retry_async.AsyncRetry (#587)
- from version 2.16.0
  * Retry and retry_async support streaming rpcs (#495)
- Refresh patches for new version
  * python-google-api-core-no-mock.patch
- Update BuildRequires and Requires from setup.py
* Tue Mar  5 2024 Robert Schweikert <rjschwei@suse.com>
- Obsolete Python 3.6 build for SLE 15 SP4 and openSUSE Leap 15.4 and later
* Mon Feb 26 2024 Robert Schweikert <rjschwei@suse.com>
- Version update in SLE 15 SP4 and later (jsc#PED-6697)
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 2.15.0:
  * Add support for Python 3.12
  * Add type annotations to wrapped grpc calls
  * Add universe_domain argument to ClientOptions
  * Introduce compatibility with native namespace packages
  * Fix regression in `bidi` causing `Thread-
    ConsumeBidirectionalStream caught unexpected exception  and
    will exit` (#562)
  * Replace deprecated `datetime.datetime.utcnow()`
* Thu Dec  7 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.14.0
  * Support with_call for wrapped rpcs (#550)
- from version 2.13.1
  * Update async client to use async retry (#544)
- from version 2.13.0
  * Add caching to routing header calculation (#526)
  * Add warning to retry target to avoid incorrect usage (#543)
  * Drop usage of distutils (#541)
  * Ensure exception is available when BackgroundConsumer
    open stream fails (#357)
* Mon Oct 23 2023 ecsos <ecsos@opensuse.org>
- Use correct dependencies version for protobuf.
* Thu Oct 12 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.12.0
  * Add a little bit of typing to google.api_core.retry (#453)
  * Add grpc Compression argument to channels and methods (#451)
  * Fix a typo in google/api_core/page_iterator.py (#511)
* Sun Jul  2 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue Jun 20 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.11.1
  * Add actionable errors for GCE long running operations (#498)
  * Invalid `dev` version identifiers in `setup.py` (#505)
* Fri Dec  2 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.11.0
  * Add support for Python 3.11 (#466)
  * Allow representing enums with their unqualified
    symbolic names in headers (#465)
  * Major refactoring of Polling, Retry and Timeout logic (#462)
  * Require google-auth >= 2.14.1 (#463)
- Refresh patches for new version
  * python-google-api-core-no-mock.patch
- Update BuildRequires and Requires from setup.py
* Fri Oct 14 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.10.2
  * **deps:** Allow protobuf 3.19.5 (#459)
- from version 2.10.1
  * Improve transcoding error message (#442)
* Thu Sep  8 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.10.0
  * Add 'strict' to flatten_query_params to lower-case bools (#433)
  * Make grpc transcode logic work in terms of protobuf python objects (#428)
  * Require python 3.7+ (#410)
  * Restore support for grpcio-gcp (#418)
- from version 2.8.2
  * **deps:** allow protobuf < 5.0.0 (#400)
  * drop support for grpc-gcp (#401)
  * fix changelog header to consistent size (#394)
  * Fix typo in the BackgroundConsumer docstring (#395)
- Refresh patches for new version
  * python-google-api-core-no-mock.patch
- Update BuildRequires and Requires from setup.py
* Wed Jun  8 2022 pgajdos@suse.com
- version update to 2.8.1
  2.8.1 (2022-05-26)
  Bug Fixes
  * deps: require googleapis-common-protos >= 1.56.2 (d84d66c)
  * deps: require protobuf>= 3.15.0, <4.0.0dev (#385) (d84d66c)
  2.8.0 (2022-05-18)
  Features
  * adds support for audience in client_options (#379) (c97c498)
  * adds support for audience in client_options. (c97c498)
* Thu May 12 2022 pgajdos@suse.com
- version update to 2.7.3
  Bug Fixes
  * Avoid AttributeError if grpcio-status is not installed (#370) (022add1)
- deleted patches
  - 373-KeyError-in-test.patch (upstreamed)
* Thu May 12 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches
  fix no mock
  + python-google-api-core-no-mock.patch
* Mon Apr 25 2022 Matej Cepl <mcepl@suse.com>
- Update to 2.7.2:
  - allow grpc without grpcio-status
  - remove dependency on pkg_resources
- Add 373-KeyError-in-test.patch to allow tests to run
  (gh#googleapis/python-api-core#372)
* Thu Apr  7 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.7.1
  Bug Fixes
  * add more context to error message. (#340)
- from version 2.7.0
  Features
  * expose extra fields in ExtendedOperation (#351)
- from version 2.6.1
  Bug Fixes
  * Remove py2 tag from wheel (#343)
- from version 2.6.0
  Features
  * initial support for Extended Operations (#344)
- from version 2.5.0
  Features
  * add api_key to client options (#248)
  Bug Fixes
  * **deps:** remove setuptools from dependencies (#339)
  Documentation
  * fix typo in library name (#332)
- from version 2.4.0
  Features
  * add support for 'error_info' (#315)
  * iterator for processing JSON responses in REST streaming. (#317)
- from version 2.3.2
  Bug Fixes
  * address broken wheels in version 2.3.1
- from version 2.3.1
  Bug Fixes
  * exclude function target from retry deadline exceeded exception message (#318)
- from version 2.3.0
  Features
  * add operations rest client to support long-running operations. (#311)
  Bug Fixes
  * handle bare 'grpc.Call' in 'from_grpc_error' (#298)
- from version 2.2.2
  Bug Fixes
  * make 'gapic_v1.method.DEFAULT' a typed object (#292)
- from version 2.2.1
  Bug Fixes
  * revert "fix: do not error on LROs with no response or error" (#294)
- from version 2.2.0
  Features
  * add 'GoogleAPICallError.error_details' property (#286)
- from version 2.1.1
  Bug Fixes
  * add mypy checking + 'py.typed' file (#290)
- from version 2.1.0
  Features
  * add grpc transcoding + tests (#259)
  * Add helper function to format query_params for rest transport. (#275)
  * add support for Python 3.10 (#284)
- Update BuildRequires and Requires from setup.py
* Tue Sep  7 2021 Steve Kowalik <steven.kowalik@suse.com>
- To avoid a build cycle, switch to multibuild.
* Mon Sep  6 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.0.1:
  * do not error on LROs with no response or error (#258) (618f192)
  * drop support for Python 2.7 / 3.5 (#212) (a30f004)
  * bump grpcio version to use stable aio API (#234) (bdbf889)
  * strip trailing _ from field mask paths (#228) (ff6ef1b)
  * add 'requests.exceptions.ChunkedEncodingError' to retryable exceptions
    (#237) (5e540f2)
  * add ServiceUnavailable exception to polling retries (#184) (11032cf)
  * undprecate entity factory helpers (#101) (1fbee03), closes #100
  * add iterator capability to paged iterators (#200) (3487d68)
  * HTTPIterator now accepts a page_size parameter to control page
    (#197) (a421913)
  * Add support for rest/ token in x-goog-api-client header (#189) (15aca6b)
  * retry google.auth TransportError and requests ConnectionError
    (#178) (6ae04a8)
  * skip empty policy bindings in len() and iter() (#159) (9eaa786)
  * save empty IAM policy bindings (#155) (536c2ca)
  * add operation name to x-goog-request-params in async client
    (#137) (7271b23)
  * allow default_host and default_scopes to be passed to create_channel
    (#134) (94c76e0)
  * add operation name to x-goog-request-params (#133) (97cef4a)
  * allow gRPC metadata to be passed to operations client (#127) (73854e8)
- Refresh {Build,}Requires, adding pytest-asyncio and proto-plus.
* Wed Jan  6 2021 Matthias Fehring <buschmann23@opensuse.org>
- Skip build on python2 as it is not supported anymore
* Wed Jan  6 2021 Matthias Fehring <buschmann23@opensuse.org>
- Update to 1.24.1
  * support 'retry' for ops built from HTTP/gRPC responses
    (gh#googleapis/python-api-core#115)
- from version 1.24.0
  * add support for Python 3.9, drop support for Python 3.5
    (gh#googleapis/python-api-core#111)
- from version 1.23.0
  * api-core: pass retry from result() to done()
    (gh#googleapis/python-api-core#9)
  * map LRO errors to library exception types
    (gh#googleapis/python-api-core#15)
* Wed Oct  7 2020 John Vandenberg <jayvdb@gmail.com>
- Update URL to match PyPI: https://github.com/googleapis/python-api-core
- Update to v1.22.4
  * use version.py instead of pkg_resources.get_distribution
- from v1.22.3
  * require six >= 1.13.0
* Thu Sep 10 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.22.2
  * only add quota project id if supported (#75)
- from version 1.22.1
  * fix spelling errors for amount in retry (#69)
- from version 1.22.0
  * allow quota project to be passed to create_channel (#58)
  * _determine_timeout problem handling float type timeout (#64)
  * change the documentation for using 'six.moves.collections_abc.Mapping'
    instead of 'dict' in 'client_options.from_dict()' (#53)
- from version 1.21.0
  * allow credentials files to be passed for channel creation (#50)
- from version 1.20.1
  * **dependencies:** increase protobuf version (#49), closes (#48)
- from version 1.20.0
  * allow disabling response stream pre-fetch (#30), closes (#25)
- from version 1.19.1
  * bump up grpcio minimum version to 1.29.0 (#41)
- from version 1.19.0
  * **client_options:** add new client options 'quota_project_id', 'scopes',
    and 'credentials_file'
- from version 1.18.0
  * [CBT-6 helper] Exposing Retry._deadline as a property (#20)
  * add client_encryped_cert_source to ClientOptions (#31)
  * AsyncIO Integration [Part 2] (#28), closes (#23)
  * First batch of AIO integration (#26)
  * third batch of AsyncIO integration (#29)
- Update BuildRequires and Requires from setup.py
* Fri Aug 28 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix dependency on google-auth to have proper version constrain
* Thu Aug 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Disable test test___call___and_execute_retry_hitting_deadline
  to make leap buildable
* Tue Jun  2 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.17.0:
  * api_core: add retry param into PollingFuture() and it’s inheritors (#9923) (14f1f34), closes #6197
  * api-core: add client_cert_source to ClientOptions (#17) (748c935)
  * consume part of StreamingResponseIterator to support failure while under a retry context (#10206) (2b103b6)
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix condition for py2 only packages
* Wed Apr  8 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.16.0
  * feat(storage): support optionsRequestedPolicyVersion
  * feat(api_core): support version 3 policy bindings
  * Make the last retry happen at deadline.
  * Add a repr method for ClientOptions.
  * Provide a raw_page field for page_iterator.Page.
* Mon Aug 12 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.14.2
  * Forward ‘timeout’ arg from ‘exception’ to _blocking_poll.
  * Update intersphinx mapping for requests.
  * Firestore: Add should_terminate predicate for clean BiDi shutdown.
  * Update pins of ‘googleapis-common-protos.
* Tue Jul  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.13.0:
  * Various fixes for new updated dependencies
* Thu May 16 2019 kwu@suse.com
- Update to 1.11.0:
  * Refactor ‘client_info’ support. (#7849)
* Tue Mar 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.8.2:
  * Remove classifier for Python 3.4 for end-of-life. (#7535)
* Thu Mar 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.8.1:
  * Protect the creation of a background thread in BackgroundConsumer and wait on it starting. (#7499)
  * Add support to unwrap Anys into wrapped pb2 objects. (#7430)
  * Add Operation.deserialize. (#7427)
* Mon Feb 18 2019 John Vandenberg <jayvdb@gmail.com>
- Activate tests
- Update to version 1.7.0
  * New Features
    + Support converting DatetimeWithNanos to / from
    google.protobuf.timestamp_pb2.Timestamp
  * Documentation
    + Document Python 2 deprecation. (#6910)
    + Add usage example for google.api_core.iam.Polcy. (#6855)
  * Internal / Testing Changes
    + Work around pytype big for ABCMeta.register
- from version 1.6.0
  (not documented)
- from version 1.5.2
  * Implementation Changes
    + Retry transient errors in 'PollingFuture.result'
  * Dependencies
    + Remove hyphen from named extra in api_core. (#6468)
    + Bump minimum 'api_core' version for all GAPIC libs to 1.4.1. (#6391)
    + Avoid broken 'google-common-apis 1.5.4' release
- from version 1.5.1
  * Implementation Changes
    + Don't URL-encode slashes in gRPC request headers
  * Internal / Testing Changes
    + Back out changes from #6267
- from version 1.5.0
  * New Features
    + Add bidi, Bidirection Streaming, to api-core
  * Internal / Testing Changes
    + Use new Nox
- from version 1.4.1
  * Internal / Testing Changes
    + Add type-checking via pytype to api_core
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Sep 12 2018 Thomas Bechtold <tbechtold@suse.com>
- update to version 1.4.0
  * Add support for gRPC connection management (available when using
    optional grpc_gcp dependency) (#5553) (#5904)
  * Update classifiers to drop Python 3.4 and add Python 3.7 (#5702)
  * Add protobuf_helpers.field_mask to calculate a field mask from
    two messages (#5320)
* Tue May 29 2018 tbechtold@suse.com
- update to 1.2.0:
  * Add close method to grpc Channel (#5333)
  * Fix tests after grpcio update (#5333)
  * Add Test runs for Python 3.7 and remove 3.4 (#5295)
- use %%license
* Fri May 18 2018 tbechtold@suse.com
- Initial packaging (version 1.1.2)
